import React from 'react'
import { get, has } from 'lodash'
import { reduxForm } from 'redux-form'
import { compose, withProps } from 'recompose'
import { Button, RadioGroup, ValidatedField } from '@pubsweet/ui'

import {
  Row,
  Item,
  Text,
  Label,
  Textarea,
  OpenModal,
  ContextualBox,
  RowOverrideAlert,
} from '../'

const options = [
  { label: 'Accept', value: 'accept' },
  { label: 'Decline', value: 'decline' },
]

const HandlingEditorAnswer = ({
  disabled,
  handleSubmit,
  shouldShowComments,
}) => (
  <ContextualBox label="Respond to Editorial Invitation">
    <RowOverrideAlert justify="flex-start" ml={1} mt={1}>
      <Item vertical>
        <Label required>
          Do you agree to be the handling editor for this manuscript?
        </Label>
        <ValidatedField
          component={input => (
            <RadioGroup inline name="decision" options={options} {...input} />
          )}
          name="decision"
        />
      </Item>
    </RowOverrideAlert>

    {shouldShowComments && (
      <RowOverrideAlert ml={1} mt={2}>
        <Item vertical>
          <Label>
            Decline Reason{' '}
            <Text secondary small>
              Optional
            </Text>
          </Label>
          <ValidatedField component={Textarea} name="reason" />
        </Item>
      </RowOverrideAlert>
    )}

    <Row justify="flex-end" mb={1} pr={1}>
      <OpenModal
        onConfirm={modalProps => handleSubmit()(modalProps)}
        title="Are you sure?"
      >
        {showModal => (
          <Button disabled={disabled} onClick={showModal} primary size="medium">
            RESPOND TO INVITATION
          </Button>
        )}
      </OpenModal>
    </Row>
  </ContextualBox>
)

export default compose(
  withProps(({ formValues }) => ({
    disabled: !has(formValues, 'decision'),
    shouldShowComments: get(formValues, 'decision', 'agree') === 'decline',
  })),
  reduxForm({
    form: 'he-answer-invitation',
    onSubmit: (values, dispatch, { onResponse }) => modalProps => {
      onResponse(values, modalProps)
    },
  }),
)(HandlingEditorAnswer)
